@@ -1,11 +1,12 @@
-import smtpd, base64, secure_smtpd
+import smtpd, base64, secure_smtpd, asynchat
 from asyncore import ExitNow
 from smtpd import NEWLINE, EMPTYSTRING
 
 class SMTPChannel(smtpd.SMTPChannel):
     
-    def __init__(self, smtp_server, newsocket, fromaddr, require_authentication=False, credential_validator=None, debug=False):
+    def __init__(self, smtp_server, newsocket, fromaddr, require_authentication=False, credential_validator=None, debug=False, map=None):
         smtpd.SMTPChannel.__init__(self, smtp_server, newsocket, fromaddr)
+        asynchat.async_chat.__init__(self, newsocket, map=map)
         self.require_authentication = require_authentication
         self.authenticating = False
         self.authenticated = False
@@ -48,8 +49,8 @@ class SMTPChannel(smtpd.SMTPChannel):
                 self.push('334 ' + base64.b64encode('Username'))
                 
         elif not self.username:
-                self.username = base64.b64decode( arg )
-                self.push('334 ' + base64.b64encode('Password'))
+            self.username = base64.b64decode( arg )
+            self.push('334 ' + base64.b64encode('Password'))
         else:
             self.authenticating = False
             self.password = base64.b64decode(arg)
@@ -59,7 +60,9 @@ class SMTPChannel(smtpd.SMTPChannel):
             else:
                 self.push('454 Temporary authentication failure.')
                 raise ExitNow()
-            
+    
+    # This code is taken directly from the underlying smtpd.SMTPChannel
+    # support for AUTH is added.
     def found_terminator(self):
         line = EMPTYSTRING.join(self.__line)
         
